summaryrefslogtreecommitdiff
path: root/geneticone.py
diff options
context:
space:
mode:
authornecoro <>2006-10-26 20:41:52 +0000
committernecoro <>2006-10-26 20:41:52 +0000
commitf8bcb199cd5569dba9039c0286456a2d651a22a8 (patch)
treed8f74c57db1e652b2dc5fbff9392dbf8502d2129 /geneticone.py
parent61d1ee1fcd985a47bebed104f6eb9e6397e5d303 (diff)
downloadportato-f8bcb199cd5569dba9039c0286456a2d651a22a8.tar.gz
portato-f8bcb199cd5569dba9039c0286456a2d651a22a8.tar.bz2
portato-f8bcb199cd5569dba9039c0286456a2d651a22a8.zip
Changed all occurences of "Necoro d.M." into "René 'Necoro' Neumann"
Diffstat (limited to '')
-rwxr-xr-xgeneticone.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/geneticone.py b/geneticone.py
index 528b45e..cee8218 100755
--- a/geneticone.py
+++ b/geneticone.py
@@ -4,12 +4,12 @@
# File: geneticone.py
# This file is part of the Genetic/One-Project, a graphical portage-frontend.
#
-# Copyright (C) 2006 Necoro d.M.
+# Copyright (C) 2006 René 'Necoro' Neumann
# This is free software. You may redistribute copies of it under the terms of
# the GNU General Public License version 2.
# There is NO WARRANTY, to the extent permitted by law.
#
# Written by Necoro d.M. <necoro@necoro.net>
from geneticone.gui import MainWindow
import sys
@@ -17,12 +17,12 @@ import sys
if __name__ == "__main__":
if len(sys.argv) > 1 and sys.argv[1] in ("--help","--version","-h","-v"):
print """Genetic/One SVN-Version
-Copyright (C) 2006 Necoro d.M.
+Copyright (C) 2006 René 'Necoro' Neumann
This is free software. You may redistribute copies of it under the terms of
the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.
There is NO WARRANTY, to the extent permitted by law.
-Written by Necoro d.M. <necoro@necoro.net>"""
+Written by René 'Necoro' Neumann <necoro@necoro.net>"""
else:
m = MainWindow()
m.main()
@@ -4,12 +4,12 @@
# There is NO WARRANTY, to the extent permitted by law.
#
-# Written by Necoro d.M. <necoro@necoro.net>
+# Written by René 'Necoro' Neumann <necoro@necoro.net>
from geneticone.gui import MainWindow
import sys